/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Federal        *
* Offenders Who Served in the Armed Forces report file and create a SAS dataset.         *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\USSC_Military_Offender_Datafile.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = USSC_Military_Offender_Datafile ;

DATA library.&dataset ;
INFILE datafile LRECL=169;
INPUT
   AGE_GROUP  1-8           DIFF_GROUP  9-16         RANK_GROUP  17-24     
   SENTL  25-32             SERVLNG_GROUP  33-40     RANK_NUMERIC  41-48   
   USSCIDN  49-55           SERVLNG  56-59           BRANCH  60-63         
   RC  64-67                CMBTOP  68-71            CMBTINJ  72-75        
   CMBTPTSD  76-79          PTSD  80-83              SEPYR  84-87          
   DISTYPE  88-91           SORREF  92-95            FORN  96-98           
   SENSPCAP  99-106         AGE  107-109             CASETYPE  110-112     
   MONSEX  113-115          NEWCIT  116-118          NEWRACE  119-121      
   OFFGUIDE  122-124        SENTIMP  125-127         SENTRNGE  128-130     
   VIOLENT  131-133         XCRHISSR  134-136     
   EVIDENCE_MENTAL_HEALTH  137-139   EVIDENCE_ALCOHOL_ABUSE  140-142
   ALCOHOL_ABUSE_12_MON_PRIOR  143-145   EVIDENCE_SUBS_ABUSE  146-148
   SUBS_ABUSE_12_MON_PRIOR  149-151   EMPLOYED_AT_ARREST  152-154
   EMPLOYED_ON_SENTENCING  155-157   SENTYR  158-161       
   DIFF  162-169          ;                       

LENGTH
   AGE_GROUP 3              DIFF_GROUP 3             RANK_GROUP 3          
   SENTL 3                  SERVLNG_GROUP 3          RANK_NUMERIC 3        
   USSCIDN 6                SERVLNG 3                BRANCH 3              
   RC 3                     CMBTOP 4                 CMBTINJ 3             
   CMBTPTSD 3               PTSD 3                   SEPYR 4               
   DISTYPE 3                SORREF 3                 FORN 3                
   AGE 3                    CASETYPE 3               MONSEX 3              
   NEWCIT 3                 NEWRACE 3                OFFGUIDE 3            
   SENTIMP 3                SENTRNGE 3               VIOLENT 3             
   XCRHISSR 3               EVIDENCE_MENTAL_HEALTH 3   EVIDENCE_ALCOHOL_ABUSE 3
   ALCOHOL_ABUSE_12_MON_PRIOR 3   EVIDENCE_SUBS_ABUSE 3    SUBS_ABUSE_12_MON_PRIOR 3
   EMPLOYED_AT_ARREST 3     EMPLOYED_ON_SENTENCING 3   SENTYR 4              
   DIFF 3 ;

            

RUN ;
